@@ -15,12 +15,11 @@ def _getInnerArticle_(soup, domain):
 	applicators = [
 		lambda x: x.find("article"),
 		lambda x: x.find("article"),
+		lambda x: x.find("main"),
 		lambda x: x.find("div", {"id" : "js_content"}),
-		lambda x: x.find("div", class_ = "story-body__inner"),
-		lambda x: x.find("div", class_ = "answercell"),
-		lambda x: x.find("div", class_ = "post-text"),
 		lambda x: x.find("div", {"id" : "bodyContent"}),
 		lambda x: x.find("div", {"id" : "content_JS"}),
+		# lambda x: x.find("div", {"id" : "article-body"}),
 		lambda x: x.find("div", class_ = "main-post"),
 		lambda x: x.find("div", class_ = "article"),
 		lambda x: x.find("div", class_ = "field-name-body"),
@@ -28,7 +27,16 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "u-content"),
 		lambda x: x.find("div", class_ = "RichContent-inner"),
 		lambda x: x.find("div", class_ = "entry-content"),
-		lambda x: x.find("main", class_ = 'main-content'),
+		lambda x: x.find("div", class_ = 'pf-content'),
+		lambda x: x.find("div", class_ = 'pn-single-post-wrapper__content'),
+		lambda x: x.find("div", class_ = 'post-content'),
+		lambda x: x.find("div", class_ = 'inner_content'),
+		lambda x: x.find("div", class_ = 'content_wrapper'),
+		lambda x: x.find("div", class_ = "story-body__inner"),
+		lambda x: x.find("div", class_ = "answercell"),
+		lambda x: x.find("div", class_ = "post-text"),
+		lambda x: x.find("div", class_ = "post-body"),
+		lambda x: x.find("div", class_ = "mainContent"),
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
@@ -43,6 +51,9 @@ def _getInnerArticle_(soup, domain):
 			lambda x: x.find('div', class_ = 'news_part')],
 		'gravitysworm': [lambda x: x.find("div", class_ = "copy")],
 		'opinion.cw.com.tw': [lambda x: x.find("article"),],
+		'chinaworker.': [lambda x: x.find("div", class_ = 'pf-content'),],
+		'thesocietypages.org': [lambda x: x.find("div", class_ = 'post-content'),],
+		'chinadigitaltimes.': [lambda x: x.find("div", class_ = 'post-content'),],
 	}
 	is_short = matchKey(soup.text, SHORT_ARTICLE)
 	text_limit = 150 if is_short else 500
