@@ -26,11 +26,13 @@ OFFTOPIC_ATT = [
 	'list-unstyled', 'hide_word', 'single-header', 'post-pagination',
 	'weui-dialog', 'post-title', 'post-topic', 'byline-date', 'post-print',
 	'mailing-list-popup', 'taxonomies', 'authors', 'interactive-content',
-	'socialBTN', 'page-view',
+	'socialBTN', 'page-view', 'pn-single-post-wrapper__social', 'pn-pagicle-widget',
+	'mashsb-container', 'give-form-wrap', 'story_bady_info_author',
+	'taglist', 'donate'
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
-	'sidebar': ['no-sidebar', 'one-sidebar', 'penci-main', 'id : page'],
+	'sidebar': ['no-sidebar', 'one-sidebar', 'penci-main', 'id : page', 'single-post'],
 	'hidden': ['lazy', 'false', 'label-hidden', 'rich_media_content', 'start', 'overflow'],
 	'navigation': ['navigation-border-thin-decoration'],
 	'copyright': ['and'],
@@ -49,7 +51,8 @@ P_AD_WORDS = [
 	'The Times is committed', 
 	'Follow The New York Times',
 	'Love HuffPost',
-	'discounted subscription today'
+	'discounted subscription today',
+	'Just follow this link',
 ]
 
 def _isOffTopic(attrs):
